@@ -4,8 +4,7 @@ from unsafe.utils.proxy import Proxy
 from unsafe.utils.bruteforce import BruteForcer
 from unsafe.utils.wp import Wordpress
 from unsafe.utils.exifdata import ExifImage
-# from unsafe.utils.anonymous import Anonymous
-from unsafe.utils.seeker import Seeker
+from unsafe.utils.crawler import Crawler
 from queue import Queue
 
 
@@ -16,16 +15,17 @@ class Unsafe(
     BruteForcer,
     Wordpress,
     ExifImage,
-    # Anonymous,
-    Seeker
+    Crawler
 ):
     def __init__(self):
         self.admin_finder_queue = Queue()
         self.file_manager_queue = Queue()
         self.cloudflare_subdomain_bypasser = Queue()
         self.zip_cracker_queue = Queue()
+        self.subdomain_scanner_queue = Queue()
         self.admin_finder_founded = []
         self.file_manager_founded = []
         self.subdomain_bypassed = {}
         self.zip_threads = []
         self.zip_password_founded = []
+        self.subdomain_founded = []
